pro sxl_clip,data,out,width=width,level=level,keep=keep,verbose=verbose,$
   noplot=noplot,ii=ii

;+
; NAME
;	sxl_clip
; PURPOSE
; 	Written to identify extra high or low SXL flux values.
;       Plot results for eyeball judgment of effectiveness.
; CALLING SEQUENCE
;	sxl_clip,data,out [,ii=ii,width=width,level=level,/verbose $
;		,/keep,/verbose]
; INPUT
;	data, data array from sxl_analysis to clip, e.g, data(0,*).
; OPTIONAL KEYWORD INPUT
;       ii, array of indices to process.  Default:  All data.
;	width, smoothing width.  Default:  17
;	level, +/- clipping level.  Default:  0.25
;	/keep, return the indices of unclipped data.
;       /verbose, print out "help" listings of input and output arrays.
;	/noplot, skip plot output
; OUTPUT
;	out, vector of indices of rejected or accepted (/keep)
;	     data points.  I.e., if array ii is input then output
;	     is out=ii(rejected) or out=ii(accepted).
; HISTORY
; 	11/18/95, LWA, written.
;	12/08/95, LWA, cleaned up and generalized.
;	12/11/95, LWA, added keyword verbose.
;	 8/10/98, LWA, put in test for negative values.
;		       put in forgotten keyword ii.
;-

siz=size(data)
if NOT keyword_set(ii) then ii=lindgen(siz(siz(0))) else ii=ii
if NOT keyword_set(width) then width=17 else width=width
if NOT keyword_set(level) then level=0.25 else level=level

; Eliminate negative values
neg=where(data le 0,mm)
if mm gt 0 then begin
   pos=where(data(ii) gt 0)
   ii2=ii(pos)
endif

xx=lindgen(n_elements(ii2))
dat=alog10(data(ii2))-alog10(big_smooth(data(ii2),width))

if NOT keyword_set(noplot) then plot,xx,dat,psym=3,yr=[-1,1]

if keyword_set(keep) then begin
   ng=where((dat lt level) and (dat gt (-level)),nn)
endif else begin
   ng=where((dat gt level) or (dat lt (-level)),nn)
endelse


if (nn ne 0) then begin
   if NOT keyword_set(noplot) then begin
      oplot,xx(ng),dat(ng),psym=4,symsize=2
      oplot,[min(xx),max(xx)],[-level,-level]
      oplot,[min(xx),max(xx)],[level,level]
   endif
   if keyword_set(keep) then begin
      out=ii(ii2(ng))
   endif else begin
      out=[ii2(ng),neg]
      out=out(sort(out))
   endelse
endif else begin
   out=-1
endelse

if keyword_set(verbose) then help,data,ii,width,level,xx,out

end

